@@ -9,7 +9,7 @@ extends qw|Text::vCard::Precisely::V3::Node::Tel Text::vCard::Precisely::V4::Nod
 
 subtype 'v4Tel'
     => as 'Str'
-    => where { m/^(:?tel:)?(:?[+]?\d{1,2}|\d*)[\(\s\-]?\d{1,3}[\)\s\-]?[\s]?\d{1,3}[\s\-]?\d{3,4}$/s }
+    => where { m/^(?:tel:)?(?:[+]?\d{1,2}|\d*)[\(\s\-]?\d{1,3}[\)\s\-]?[\s]?\d{1,3}[\s\-]?\d{3,4}$/s }
     => message { "The Number you provided, $_, was not supported in Tel" };
 has content => (is => 'ro', default => '', isa => 'v4Tel' );
 
@@ -22,10 +22,11 @@ override 'as_string' => sub {
     push @lines, 'TYPE=' . join( ',', map { uc $_ } @{ $self->types } ) if @{ $self->types || [] } > 0;
     push @lines, 'VALUE=uri';
 
-    ( my $value = $self->content ) =~ s/[-+()\s]+/ /sg;   # symbols to space
-    $value =~ s/^\s+//s;                                # remove top space
-    $value =~ s/^(:?tel\:)//s;                          # remove top 'tel:' once
-    my $string = join(';', @lines ) . ':tel:' . $value;
+    ( my $content = $self->content() ) =~ s/^\s+//s;    # remove top space
+    $content =~ s/^tel:\(?//s;                          # remove tel: once
+    $content =~ s/(?:(?!\A)\D|\()+/ /sg;                # replace symbols to space
+    $content =~ s/^\s+//s;                              # remove top space again
+    my $string = join(';', @lines ) . ':tel:' . $content;
     return $self->fold( $string, -force => 1 );
 };
 
